-- [[ insert your plugins below ]]

return {
  -- [[ Null ]]
  ({'jose-elias-alvarez/null-ls.nvim',
  config = function ()
    local null_ls = require("null-ls")

    null_ls.setup({
        sources = {
            null_ls.builtins.formatting.stylua,
            null_ls.builtins.diagnostics.eslint,
            null_ls.builtins.completion.spell,
        },
    })
  end
}),
    -- [[ Eyecandy & fancy prgramming stuff ]]

  {'tpope/vim-sleuth'}, -- Detect tabstop and shiftwidth automatically

  {'matze/vim-move'},

  {'windwp/nvim-autopairs',
  config = function ()
    require('nvim-autopairs').setup()
  end
  },

  {'tpope/vim-surround'},

  {'lilydjwg/colorizer'},

  {'stevearc/dressing.nvim',
  config = function()
    require('dressing').setup()
  end
  },

  {"yamatsum/nvim-cursorline",
  config = function()
      require('nvim-cursorline').setup {
        cursorline = {
          enable = false,
          timeout = 1000,
          number = false,
        },
        cursorword = {
          enable = true,
          min_length = 2,
          hl = { underline = true },
        }
      }
  end
  },

  -- [[ Markdown Preview ]]

  -- Preview in browser
  {
  "iamcco/markdown-preview.nvim",
  build = "cd app && npm install",
  config = function()
      vim.g.mkdp_filetypes = { "markdown" }
      vim.g.mkdp_page_title = "${name}"
      vim.g.mkdp_markdown_css = vim.fn.stdpath("config") .. "/assets/markdown.css"
  end,
  ft = { "markdown" },
  },

      -- Table mode
      -- https://github.com/dhruvasagar/vim-table-mode
  {
  "dhruvasagar/vim-table-mode",
  ft = { "markdown" },
  config = function()
    -- Bug: changing prefix doesn't work https://github.com/dhruvasagar/vim-table-mode/issues/222
    -- :h table-mode-mappings
    -- For Markdown-compatible tables use
    vim.g.table_mode_map_prefix = "<localleader>t"
    vim.g.table_mode_corner = "|"
    -- vim.cmd("let g:table_mode_map_prefix = '<localleader>t'")
    -- vim.g.toggle_mode_options_toggle_map = "<localleader>tm"
    -- vim.g.table_mode_commands_tableize = "<localleader>tt"
  end,
  },

  -- [[ notes ]]

  {"renerocksai/telekasten.nvim",
  dependencies = {
    {'mzlogin/vim-markdown-toc'},
    {'renerocksai/calendar-vim'},
  },
  config = function()
      require('telekasten').setup({
      home = vim.fn.expand("~/zettelkasten"), -- Put the name of your notes directory here
      })
  end
  },

  -- [[ Zen mode ]]
  'folke/zen-mode.nvim',
      dependencies = {'folke/twilight.nvim'},
      config = function ()
          require("zen-mode").setup({
            window = {
              width = .75, -- width will be 85% of the editor width
            options = {
              number = false,
              relativenumber = false,
              },
            }
          })
      end,
}
